<?php
/**
 * Customizer setup.
 *
 * @package Outer\Customizer
 */

namespace Outer\Customizer;

use Outer\Customizer\ControlTypes\Divider_Control;
use Outer\Customizer\ControlTypes\Range_Slider_Control;
use Outer\Customizer\ControlTypes\Switcher_Control;
use Outer\Customizer\ControlTypes\Alpha_Color_Picker_Control;
use Outer\Customizer\ControlTypes\Responsive_Control;
use Outer\Customizer\ControlTypes\Multiple_Select_Control;
use Outer\Customizer\ControlTypes\Toggle_Switch_Control;
use Outer\Fonts\Fonts;
use function Outer\Core\get_script_suffix;

/**
 * Set up Customizer hooks.
 *
 * @return void
 */
function setup() {
	$n = function( $function ) {
		return __NAMESPACE__ . "\\$function";
	};

	add_action( 'customize_register', $n( 'register_control_types' ) );
	add_action( 'customize_register', $n( 'default_controls' ) );
	add_action( 'customize_register', $n( 'register_panels_sections' ) );
	add_action( 'customize_register', $n( 'register_color_controls' ) );
	add_action( 'customize_register', $n( 'register_typo_controls' ) );
	add_action( 'customize_register', $n( 'register_button_controls' ) );
	add_action( 'customize_register', $n( 'register_layout_controls' ) );
	add_action( 'customize_register', $n( 'register_header_controls' ) );
	add_action( 'customize_register', $n( 'register_footer_controls' ) );
	add_action( 'customize_preview_init', $n( 'customize_preview_init' ) );
	add_action( 'customize_controls_enqueue_scripts', $n( 'customize_controls_assets' ) );

	require_once get_parent_theme_file_path( 'inc/customizer/helpers.php' ); // phpcs:ignore
	require_once get_parent_theme_file_path( 'inc/customizer/styles.php' ); // phpcs:ignore
}
/**
 * Register our custom control types.
 *
 * @param \WP_Customize_Manager $wp_customize The customizer object.
 *
 * @return void
 */
function register_control_types( \WP_Customize_Manager $wp_customize ) {
	// This file is a class for our Customizer switcher control, not template partials.
	// phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/switcher-control/switcher-control.php' ); // phpcs:ignore
	// Divider control class.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/divider-control/divider-control.php' ); // phpcs:ignore
	// Alpha color picker control class.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/alpha-color-picker-control/alpha-color-picker-control.php' ); // phpcs:ignore
	// Multiple select2.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/multiple-select-control/multiple-select-control.php' ); // phpcs:ignore
	// Responsive.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/responsive-control/responsive-control.php' ); // phpcs:ignore
	// Range slider control.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/range-slider-control/range-slider-control.php' ); // phpcs:ignore
	// Toggle Switch control.
	require_once get_parent_theme_file_path( 'inc/customizer/control-types/toggle-switch-control/toggle-switch-control.php' ); // phpcs:ignore

	$wp_customize->register_control_type( Switcher_Control::class );
	// Register Responsive Custom Control.
	$wp_customize->register_control_type( Responsive_Control::class );
}

/**
 * Enqueues the preview js for the customizer.
 *
 * @return void
 */
function customize_preview_init() {

	$suffix = get_script_suffix();

	wp_enqueue_script(
		'outer-customize-preview',
		get_theme_file_uri( "assets/js/customize-preview{$suffix}.js" ),
		array( 'jquery', 'customize-preview' ),
		filemtime( get_theme_file_path( "/assets/js/customize-preview{$suffix}.js" ) ),
		true
	);
}

/**
 * Enqueues the necessary controls assets
 *
 * @return void
 */
function customize_controls_assets() {

	$suffix = get_script_suffix();

	// Conditionally register Select2 script & styles.
	if ( ! wp_script_is( 'select2', 'registered' ) && ! wp_style_is( 'select2', 'registered' ) ) {
		wp_register_style(
			'select2',
			get_parent_theme_file_uri( "assets/css/select2{$suffix}.css" ),
			array(),
			'4.0.6-rc.1'
		);
		wp_register_script(
			'select2',
			get_parent_theme_file_uri( "assets/js/select2{$suffix}.js" ),
			array( 'jquery' ),
			'4.0.6-rc.1',
			true
		);
	}

	// Load Select2 script & styles.
	wp_enqueue_style( 'select2' );
	wp_enqueue_script( 'select2' );

	// Attach Select2 Customizer Z-index patch.
	wp_add_inline_style(
		'select2',
		'.select2-container {
					z-index: 600000;
				}
			'
	);

	wp_enqueue_style(
		'outer-customize-style',
		get_theme_file_uri( "assets/css/customizer{$suffix}.css" ),
		array(),
		filemtime( get_theme_file_path( "/assets/css/customizer{$suffix}.css" ) )
	);

	wp_enqueue_script(
		'outer-customize-controls',
		get_theme_file_uri( "assets/js/customize-controls{$suffix}.js" ),
		array( 'jquery', 'customize-controls', 'select2' ),
		filemtime( get_theme_file_path( "/assets/js/customize-controls{$suffix}.js" ) ),
		true
	);

	wp_set_script_translations( 'outer-customize-controls', 'outer' );

	$fonts = Fonts::customizer_fonts_data_filtered();
	wp_localize_script(
		'outer-customize-controls',
		'fontsData',
		array(
			'fonts' => $fonts,
		)
	);
}

/**
 * Tweaks the default customizer controls.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function default_controls( \WP_Customize_Manager $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	$wp_customize->get_setting( 'custom_logo' )->transport     = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.header__title-inner',
				'render_callback' => '\\Outer\\site_branding',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.header__title-inner',
				'render_callback' => '\\Outer\\site_branding',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'custom_logo',
			array(
				'selector'        => '.header__title-inner',
				'render_callback' => '\\Outer\\site_branding',
			)
		);
	}

	$wp_customize->remove_section( 'background_image' );
}

/**
 * Register Panels & Sections
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object
 */
function register_panels_sections( \WP_Customize_Manager $wp_customize ) {

	// Panel: Theme Options.
	$wp_customize->add_panel(
		'outer_theme_options',
		array(
			'title'    => esc_html__( 'Theme Options', 'outer' ),
			'priority' => 999,
		)
	);

	// Section: Typography.
	$wp_customize->add_section(
		'outer_typo_settings',
		array(
			'title'    => esc_html__( 'Typography', 'outer' ),
			'panel'    => 'outer_theme_options',
			'priority' => 0,
		)
	);

	// Section: Button.
	$wp_customize->add_section(
		'outer_button_settings',
		array(
			'title'    => esc_html__( 'Theme Button', 'outer' ),
			'panel'    => 'outer_theme_options',
			'priority' => 5,
		)
	);

	// Section: Layout.
	$wp_customize->add_section(
		'outer_layout_settings',
		array(
			'title'    => esc_html__( 'Layout', 'outer' ),
			'panel'    => 'outer_theme_options',
			'priority' => 10,
		)
	);

	// Section: Header.
	$wp_customize->add_section(
		'outer_header_settings',
		array(
			'title'    => esc_html__( 'Header', 'outer' ),
			'panel'    => 'outer_theme_options',
			'priority' => 20,
		)
	);

	// Section: Footer.
	$wp_customize->add_section(
		'outer_footer_settings',
		array(
			'title'    => esc_html__( 'Footer', 'outer' ),
			'panel'    => 'outer_theme_options',
			'priority' => 30,
		)
	);
}

/**
 * Register Site Color Controls within Customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_color_controls( \WP_Customize_Manager $wp_customize ) {
	$settings = outer_get_setting();

	// Site Color Scheme.
	$wp_customize->add_setting(
		'site_color_scheme',
		array(
			'default'           => $settings['site_color_scheme'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\\sanitize_radio',
		)
	);

	$wp_customize->add_control(
		new Switcher_Control(
			$wp_customize,
			'site_color_scheme',
			array(
				'label'         => esc_html__( 'Color Scheme', 'outer' ),
				'description'   => esc_html__( 'Select which of the color modes will be active by default.', 'outer' ),
				'section'       => 'colors',
				'choices'       => array(
					'light' => array(
						'label'         => esc_html_x( 'Light', 'name of the second color scheme option', 'outer' ),
						'preview_image' => get_theme_file_uri( 'assets/images/svg/light-scheme.svg' ),
					),
					'dark'  => array(
						'label'         => esc_html_x( 'Dark', 'name of the third color scheme option', 'outer' ),
						'preview_image' => get_theme_file_uri( 'assets/images/svg/dark-scheme.svg' ),
					),
				),
				'switcher_type' => 'color-scheme',
				'priority'      => 1,
			)
		)
	);

	// Dark scheme body bg color.
	$wp_customize->add_setting(
		'dark_scheme_body_bg_color',
		array(
			'default'           => $settings['dark_scheme_body_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_body_bg_color',
			array(
				'label'   => esc_html__( 'Body Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark scheme text color.
	$wp_customize->add_setting(
		'dark_scheme_text_color',
		array(
			'default'           => $settings['dark_scheme_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_text_color',
			array(
				'label'   => esc_html__( 'Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark scheme accent color.
	$wp_customize->add_setting(
		'dark_scheme_accent_color',
		array(
			'default'           => $settings['dark_scheme_accent_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_accent_color',
			array(
				'label'   => esc_html__( 'Accent', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light scheme body bg color.
	$wp_customize->add_setting(
		'light_scheme_body_bg_color',
		array(
			'default'           => $settings['light_scheme_body_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_body_bg_color',
			array(
				'label'   => esc_html__( 'Body Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light scheme text color.
	$wp_customize->add_setting(
		'light_scheme_text_color',
		array(
			'default'           => $settings['light_scheme_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_text_color',
			array(
				'label'   => esc_html__( 'Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light scheme accent color.
	$wp_customize->add_setting(
		'light_scheme_accent_color',
		array(
			'default'           => $settings['light_scheme_accent_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_accent_color',
			array(
				'label'   => esc_html__( 'Accent', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Secondary aka Light Background Color.
	$wp_customize->add_setting(
		'dark_scheme_light_bg_color',
		array(
			'default'           => $settings['dark_scheme_light_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_light_bg_color',
			array(
				'label'   => esc_html__( 'Light background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Secondary aka Text over light Color.
	$wp_customize->add_setting(
		'dark_scheme_light_text_color',
		array(
			'default'           => $settings['dark_scheme_light_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_light_text_color',
			array(
				'label'   => esc_html__( 'Text over light', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Secondary aka Light Background Color.
	$wp_customize->add_setting(
		'light_scheme_light_bg_color',
		array(
			'default'           => $settings['light_scheme_light_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_light_bg_color',
			array(
				'label'   => esc_html__( 'Light background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Secondary aka Text over light Color.
	$wp_customize->add_setting(
		'light_scheme_light_text_color',
		array(
			'default'           => $settings['light_scheme_light_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_light_text_color',
			array(
				'label'   => esc_html__( 'Text over light', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Footer aka Dark Background Color.
	$wp_customize->add_setting(
		'dark_scheme_dark_bg_color',
		array(
			'default'           => $settings['dark_scheme_dark_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_dark_bg_color',
			array(
				'label'   => esc_html__( 'Dark background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Footer aka Text over dark Color.
	$wp_customize->add_setting(
		'dark_scheme_dark_text_color',
		array(
			'default'           => $settings['dark_scheme_dark_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_dark_text_color',
			array(
				'label'   => esc_html__( 'Text over dark', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Footer aka Dark Background Color.
	$wp_customize->add_setting(
		'light_scheme_dark_bg_color',
		array(
			'default'           => $settings['light_scheme_dark_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_dark_bg_color',
			array(
				'label'   => esc_html__( 'Dark background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Footer aka Text over dark Color.
	$wp_customize->add_setting(
		'light_scheme_dark_text_color',
		array(
			'default'           => $settings['light_scheme_dark_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_dark_text_color',
			array(
				'label'   => esc_html__( 'Text over dark', 'outer' ),
				'section' => 'colors',
			)
		)
	);


	/**
	 * Border Color.
	 */
	// Dark Scheme: Border Color.
	$wp_customize->add_setting(
		'dark_scheme_border_color',
		array(
			'default'           => $settings['dark_scheme_border_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_border_color',
			array(
				'label'   => esc_html__( 'Border', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Border Color.
	$wp_customize->add_setting(
		'light_scheme_border_color',
		array(
			'default'           => $settings['light_scheme_border_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);

	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_border_color',
			array(
				'label'   => esc_html__( 'Border', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	/**
	 * Dark Scheme: Expand toggle for Buttons Normal.
	 */
	$wp_customize->add_setting(
		'dark_scheme_wrap_btn_colors',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'dark_scheme_wrap_btn_colors',
			array(
				'label'      => __( 'Buttons Normal', 'outer' ),
				'toggle_ids' => '#customize-control-dark_scheme_btn_bg_color, #customize-control-dark_scheme_btn_text_color',
				'type'       => 'expand-header',
				'section'    => 'colors',
			)
		)
	);

	// Dark Scheme: Button bg color.
	$wp_customize->add_setting(
		'dark_scheme_btn_bg_color',
		array(
			'default'           => $settings['dark_scheme_btn_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_btn_bg_color',
			array(
				'label'   => esc_html__( 'Button Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Button text color.
	$wp_customize->add_setting(
		'dark_scheme_btn_text_color',
		array(
			'default'           => $settings['dark_scheme_btn_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_btn_text_color',
			array(
				'label'   => esc_html__( 'Button Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	/**
	 * Light Scheme: Expand toggle for Normal Buttons.
	 */
	$wp_customize->add_setting(
		'light_scheme_wrap_btn_colors',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'light_scheme_wrap_btn_colors',
			array(
				'label'      => __( 'Buttons Normal', 'outer' ),
				'toggle_ids' => '#customize-control-light_scheme_btn_bg_color, #customize-control-light_scheme_btn_text_color',
				'type'       => 'expand-header',
				'section'    => 'colors',
			)
		)
	);

	// Light Scheme: Button bg color.
	$wp_customize->add_setting(
		'light_scheme_btn_bg_color',
		array(
			'default'           => $settings['light_scheme_btn_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_btn_bg_color',
			array(
				'label'   => esc_html__( 'Button Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Button text color.
	$wp_customize->add_setting(
		'light_scheme_btn_text_color',
		array(
			'default'           => $settings['light_scheme_btn_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_btn_text_color',
			array(
				'label'   => esc_html__( 'Button Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	/**
	 * Dark Scheme: Expand toggle for Buttons Hover.
	 */
	$wp_customize->add_setting(
		'dark_scheme_wrap_btn_hover_colors',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'dark_scheme_wrap_btn_hover_colors',
			array(
				'label'      => __( 'Buttons Hover', 'outer' ),
				'toggle_ids' => '#customize-control-dark_scheme_btn_hover_bg_color, #customize-control-dark_scheme_btn_hover_text_color',
				'type'       => 'expand-header',
				'section'    => 'colors',
			)
		)
	);

	// Dark Scheme: Button hover bg color.
	$wp_customize->add_setting(
		'dark_scheme_btn_hover_bg_color',
		array(
			'default'           => $settings['dark_scheme_btn_hover_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_btn_hover_bg_color',
			array(
				'label'   => esc_html__( 'Button Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Dark Scheme: Button hover text color.
	$wp_customize->add_setting(
		'dark_scheme_btn_hover_text_color',
		array(
			'default'           => $settings['dark_scheme_btn_hover_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'dark_scheme_btn_hover_text_color',
			array(
				'label'   => esc_html__( 'Button Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	/**
	 * Light Scheme: Expand toggle for Buttons Hover.
	 */
	$wp_customize->add_setting(
		'light_scheme_wrap_btn_hover_colors',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'light_scheme_wrap_btn_hover_colors',
			array(
				'label'      => __( 'Buttons Hover', 'outer' ),
				'toggle_ids' => '#customize-control-light_scheme_btn_hover_bg_color, #customize-control-light_scheme_btn_hover_text_color',
				'type'       => 'expand-header',
				'section'    => 'colors',
			)
		)
	);

	// Light Scheme: Button hover bg color.
	$wp_customize->add_setting(
		'light_scheme_btn_hover_bg_color',
		array(
			'default'           => $settings['light_scheme_btn_hover_bg_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_btn_hover_bg_color',
			array(
				'label'   => esc_html__( 'Button Background', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Light Scheme: Button hover text color.
	$wp_customize->add_setting(
		'light_scheme_btn_hover_text_color',
		array(
			'default'           => $settings['light_scheme_btn_hover_text_color'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_hex_rgba',
		)
	);
	$wp_customize->add_control(
		new Alpha_Color_Picker_Control(
			$wp_customize,
			'light_scheme_btn_hover_text_color',
			array(
				'label'   => esc_html__( 'Button Text', 'outer' ),
				'section' => 'colors',
			)
		)
	);

	// Reset color controls button.
	$wp_customize->add_setting(
		'reset_scheme_colors_btn',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'reset_scheme_colors_btn',
			array(
				'label'   => __( 'Reset color scheme', 'outer' ),
				'type'    => 'reset-btn',
				'section' => 'colors',
			)
		)
	);

}

/**
 * Register Typography Controls within Customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_typo_controls( \WP_Customize_Manager $wp_customize ) {

	// Get Fonts List.
	$google_fonts = Fonts::all_font_choices();

	$settings = outer_get_setting();

	/**
	 * BODY & CONTENT.
	 */

	// Body font settings.
	$wp_customize->add_setting(
		'font_body',
		array(
			'default'           => $settings['font_body'],
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		'font_body',
		array(
			'label'   => __( 'Body Font', 'outer' ),
			'section' => 'outer_typo_settings',
			'type'    => 'select',
			'choices' => $google_fonts,
		)
	);

	$font_body_variants_list = Fonts::load_google_font_variants( 'font_body' );
	// Load body font variant settings.
	$wp_customize->add_setting(
		'font_body_load_variant',
		array(
			'default'           => $settings['font_body_load_variant'],
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_text',
		)
	);
	$wp_customize->add_control(
		new Multiple_Select_Control(
			$wp_customize,
			'font_body_load_variant',
			array(
				'label'       => __( 'Font Variant', 'outer' ),
				'section'     => 'outer_typo_settings',
				'input_attrs' => array(
					'multiselect' => true,
				),
				'choices'     => $font_body_variants_list,
			)
		)
	);

	// Base font size settings.
	$wp_customize->add_setting(
		'font_base_size',
		array(
			'default'           => $settings['font_base_size'],
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_responsive_typo',
		)
	);
	$wp_customize->add_control(
		new Responsive_Control(
			$wp_customize,
			'font_base_size',
			array(
				'label'       => __( 'Base Font Size', 'outer' ),
				'section'     => 'outer_typo_settings',
				'type'        => 'outer-responsive',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 200,
					'step' => 1,
				),
				'units'       => array(
					'px' => 'px',
				),
			)
		)
	);

	// Body font line height settings.
	$wp_customize->add_setting(
		'font_base_line_height',
		array(
			'default'           => $settings['font_base_line_height'],
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_responsive_typo',
		)
	);
	$wp_customize->add_control(
		new Responsive_Control(
			$wp_customize,
			'font_base_line_height',
			array(
				'label'       => __( 'Base Line Height', 'outer' ),
				'section'     => 'outer_typo_settings',
				'type'        => 'outer-responsive',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 2000,
					'step' => 1,
				),
				'units'       => array(
					'%' => '%',
				),
			)
		)
	);

	/**
	 * HEADINGS.
	 */
	// Headings Divider horizontal line.
	$wp_customize->add_setting(
		'font_headings_divider',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'font_headings_divider',
			array(
				'label'   => 'Type Divider',
				'type'    => 'line',
				'section' => 'outer_typo_settings',
			)
		)
	);
	// Headings font settings.
	$wp_customize->add_setting(
		'font_headings',
		array(
			'default'           => $settings['font_headings'],
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		'font_headings',
		array(
			'label'   => __( 'Heading Font', 'outer' ),
			'section' => 'outer_typo_settings',
			'type'    => 'select',
			'choices' => $google_fonts,
		)
	);

	$font_heading_variants_list = Fonts::load_google_font_variants( 'font_headings' );

	// Load heading font variant settings.
	$wp_customize->add_setting(
		'font_headings_load_variant',
		array(
			'default'           => $settings['font_headings_load_variant'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_text',
		)
	);
	$wp_customize->add_control(
		new Multiple_Select_Control(
			$wp_customize,
			'font_headings_load_variant',
			array(
				'label'       => __( 'Font Variant', 'outer' ),
				'section'     => 'outer_typo_settings',
				'input_attrs' => array(
					'multiselect' => true,
				),
				'choices'     => $font_heading_variants_list,
			)
		)
	);

	/**
	 * Font Subset.
	 */
	// Font subset divider line.
	$wp_customize->add_setting(
		'font_subset_divider',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'font_subset_divider',
			array(
				'description' => 'Type Divider',
				'type'        => 'line',
				'section'     => 'outer_typo_settings',
			)
		)
	);
	// Font character subset settings.
	$wp_customize->add_setting(
		'font_subset',
		array(
			'default'           => $settings['font_subset'],
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		'font_subset',
		array(
			'label'       => __( 'Google Font Subset', 'outer' ),
			'description' => sprintf(
			/* translators: Link to Google fonts website */
				esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'outer' ),
				sprintf(
					'<a href="%1$s" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					esc_html__( 'Google Fonts website', 'outer' )
				)
			),
			'section'     => 'outer_typo_settings',
			'type'        => 'select',
			'choices'     => Fonts::get_google_font_subsets(),
		)
	);
}

/**
 * Register theme button controls within customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_button_controls( \WP_Customize_Manager $wp_customize ) {
	$settings = outer_get_setting();

	// Get Font weights.
	$font_weights = Fonts::get_google_font_weights();

	// Get Font Text Transform array.
	$font_tt = Fonts::get_font_text_transform();

	// Button text transform.
	$wp_customize->add_setting(
		'font_btn_text_transform',
		array(
			'default'           => $settings['font_btn_text_transform'],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'font_btn_text_transform',
		array(
			'label'   => __( 'Text Transform', 'outer' ),
			'section' => 'outer_button_settings',
			'type'    => 'select',
			'choices' => $font_tt,
		)
	);

	// Button font weight.
	$wp_customize->add_setting(
		'font_btn_weight',
		array(
			'default'           => $settings['font_btn_weight'],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'font_btn_weight',
		array(
			'label'   => __( 'Font Weight', 'outer' ),
			'section' => 'outer_button_settings',
			'type'    => 'select',
			'choices' => $font_weights,
		)
	);

	// Button border radius.
	$wp_customize->add_setting(
		'btn_border_radius',
		array(
			'default'           => $settings['btn_border_radius'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_range',
		)
	);

	$wp_customize->add_control(
		new Range_Slider_Control(
			$wp_customize,
			'btn_border_radius',
			array(
				'label'       => __( 'Border Radius (px)', 'outer' ),
				'section'     => 'outer_button_settings',
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
			)
		)
	);

}

/**
 * Register layout controls within customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_layout_controls( \WP_Customize_Manager $wp_customize ) {

	$settings = outer_get_setting();

	// Content width controls title.
	$wp_customize->add_setting(
		'content_container_width_title',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'content_container_width_title',
			array(
				'description' => __( 'Content Width', 'outer' ),
				'type'        => 'heading',
				'section'     => 'outer_layout_settings',
			)
		)
	);

	// Pages container width.
	$wp_customize->add_setting(
		'pages_container_width',
		array(
			'default'           => $settings['pages_container_width'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_range',
		)
	);

	$wp_customize->add_control(
		new Range_Slider_Control(
			$wp_customize,
			'pages_container_width',
			array(
				'label'       => __( 'Pages (px)', 'outer' ),
				'section'     => 'outer_layout_settings',
				'input_attrs' => array(
					'min'  => 200,
					'max'  => 4000,
					'step' => 1,
				),
			)
		)
	);

	// Posts container width.
	$wp_customize->add_setting(
		'posts_container_width',
		array(
			'default'           => $settings['posts_container_width'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_range',
		)
	);

	$wp_customize->add_control(
		new Range_Slider_Control(
			$wp_customize,
			'posts_container_width',
			array(
				'label'       => __( 'Posts (px)', 'outer' ),
				'section'     => 'outer_layout_settings',
				'input_attrs' => array(
					'min'  => 200,
					'max'  => 1800,
					'step' => 1,
				),
			)
		)
	);

	// Blog style settings.
	$wp_customize->add_setting(
		'blog_layout_style',
		array(
			'default'           => $settings['blog_layout_style'],
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'blog_layout_style',
		array(
			'label'   => __( 'Blog Layout', 'outer' ),
			'section' => 'outer_layout_settings',
			'type'    => 'select',
			'choices' => array(
				'grid'  => __( 'Grid', 'outer' ),
				'tiled' => __( 'Tiled', 'outer' ),
			),
		)
	);

	// Blog layout column settings.
	$wp_customize->add_setting(
		'blog_layout_column',
		array(
			'default'           => $settings['blog_layout_column'],
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'blog_layout_column',
		array(
			'label'   => __( 'Columns', 'outer' ),
			'section' => 'outer_layout_settings',
			'type'    => 'select',
			'choices' => array(
				2 => __( '2', 'outer' ),
				3 => __( '3', 'outer' ),
			),
		)
	);

	$pages = get_pages();
	// Hidden page titles option.
	$wp_customize->add_setting(
		'pages_hidden_title',
		array(
			'default'           => $settings['pages_hidden_title'],
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_text',
		)
	);
	$wp_customize->add_control(
		new Multiple_Select_Control(
			$wp_customize,
			'pages_hidden_title',
			array(
				'label'       => __( 'Hide titles for Pages', 'outer' ),
				'description' => __( 'You can select multiple pages here.', 'outer' ),
				'section'     => 'outer_layout_settings',
				'input_attrs' => array(
					'multiselect' => true,
				),
				'choices'     => $pages,
			)
		)
	);

}

/**
 * Register Header Controls within Customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_header_controls( \WP_Customize_Manager $wp_customize ) {

	$settings = outer_get_setting();

	// Retinafy site logo.
	$wp_customize->add_setting(
		'site_logo_retina',
		array(
			'default'           => $settings['site_logo_retina'],
			'transport'         => 'refresh',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'site_logo_retina',
			array(
				'label'    => esc_html__( 'Retinafy Site Logo', 'outer' ),
				'section'  => 'title_tagline',
				'type'     => 'checkbox',
				'priority' => 8,
			)
		)
	);

	// Header layout variations.
	$wp_customize->add_setting(
		'header_layout_variations',
		array(
			'default'           => $settings['header_layout_variations'],
			'transport'         => 'refresh',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'header_layout_variations',
		array(
			'label'    => esc_html__( 'Header Layout', 'outer' ),
			'section'  => 'outer_header_settings',
			'type'     => 'radio',
			'choices'  => array(
				'default'  => esc_html_x( 'Default', 'name of the first layout option', 'outer' ),
				'centered' => esc_html_x( 'Centered', 'name of the second layout option', 'outer' ),
			),
			'priority' => 1,
		)
	);

	// Enable header icons title.
	$wp_customize->add_setting(
		'enable_header_toggles_title',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'enable_header_toggles_title',
			array(
				'description' => __( 'Header Toggles', 'outer' ),
				'type'        => 'heading',
				'section'     => 'outer_header_settings',
			)
		)
	);

	// Search toggle.
	$wp_customize->add_setting(
		'search_btn_toggle',
		array(
			'default'           => $settings['search_btn_toggle'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'search_btn_toggle',
			array(
				'label'   => esc_html__( 'Search', 'outer' ),
				'section' => 'outer_header_settings',
				'type'    => 'checkbox',
			)
		)
	);

	if ( outer_is_woocommerce_activated() ) {
		// Cart widget toggle.
		$wp_customize->add_setting(
			'cart_widget_toggle',
			array(
				'default'           => $settings['cart_widget_toggle'],
				'transport'         => 'postMessage',
				'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
			)
		);
		$wp_customize->add_control(
			new Toggle_Switch_Control(
				$wp_customize,
				'cart_widget_toggle',
				array(
					'label'   => esc_html__( 'Cart', 'outer' ),
					'section' => 'outer_header_settings',
					'type'    => 'checkbox',
				)
			)
		);

		// Account button.
		$wp_customize->add_setting(
			'account_btn',
			array(
				'default'           => $settings['account_btn'],
				'transport'         => 'postMessage',
				'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
			)
		);
		$wp_customize->add_control(
			new Toggle_Switch_Control(
				$wp_customize,
				'account_btn',
				array(
					'label'   => esc_html__( 'Account', 'outer' ),
					'section' => 'outer_header_settings',
					'type'    => 'checkbox',
				)
			)
		);
	}

	// Light/Dark mode toggle.
	$wp_customize->add_setting(
		'color_scheme_toggle',
		array(
			'default'           => $settings['color_scheme_toggle'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'color_scheme_toggle',
			array(
				'label'   => esc_html__( 'Light / Dark mode', 'outer' ),
				'section' => 'outer_header_settings',
				'type'    => 'checkbox',
			)
		)
	);
}

/**
 * Register Footer Controls within Customize.
 *
 * @param \WP_Customize_Manager $wp_customize The customize manager object.
 *
 * @return void
 */
function register_footer_controls( \WP_Customize_Manager $wp_customize ) {

	$settings = outer_get_setting();

	// Footer CTA Block.
	$wp_customize->add_setting(
		'footer_cta_block',
		array(
			'default'           => $settings['footer_cta_block'],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'footer_cta_block',
		array(
			'label'       => esc_html__( 'CTA Block', 'outer' ),
			'description' => esc_html__( 'To add a CTA block, save any editor block as "Reusable Block".', 'outer' ),
			'section'     => 'outer_footer_settings',
			'type'        => 'select',
			'choices'     => get_reusable_blocks(),
		)
	);

	// CTA Block helper description.
	$wp_customize->add_setting(
		'footer_cta_block_help_description',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'footer_cta_block_help_description',
			array(
				'description' => sprintf(
					'<a href="%s" target="_blank">%s</a>',
					esc_url( get_admin_url() . 'edit.php?post_type=wp_block' ),
					__( 'Manage re-usable blocks here', 'outer' )
				),
				'type'        => 'text',
				'section'     => 'outer_footer_settings',
			)
		)
	);

	// CTA Block toggles title.
	$wp_customize->add_setting(
		'footer_cta_block_toggles_title',
		array(
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new Divider_Control(
			$wp_customize,
			'footer_cta_block_toggles_title',
			array(
				'description' => __( 'Display on', 'outer' ),
				'type'        => 'heading',
				'section'     => 'outer_footer_settings',
			)
		)
	);

	// CTA Block: Homepage toggle.
	$wp_customize->add_setting(
		'footer_cta_homepage_toggle',
		array(
			'default'           => $settings['footer_cta_homepage_toggle'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'footer_cta_homepage_toggle',
			array(
				'label'   => __( 'Homepage', 'outer' ),
				'section' => 'outer_footer_settings',
				'type'    => 'checkbox',
			)
		)
	);

	// CTA Block: Single Posts.
	$wp_customize->add_setting(
		'footer_cta_single_posts_toggle',
		array(
			'default'           => $settings['footer_cta_single_posts_toggle'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'footer_cta_single_posts_toggle',
			array(
				'label'   => __( 'Single Posts', 'outer' ),
				'section' => 'outer_footer_settings',
				'type'    => 'checkbox',
			)
		)
	);

	// CTA Block: Blog Archives.
	$wp_customize->add_setting(
		'footer_cta_blog_archives_toggle',
		array(
			'default'           => $settings['footer_cta_blog_archives_toggle'],
			'transport'         => 'postMessage',
			'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Toggle_Switch_Control(
			$wp_customize,
			'footer_cta_blog_archives_toggle',
			array(
				'label'   => __( 'Blog Archives', 'outer' ),
				'section' => 'outer_footer_settings',
				'type'    => 'checkbox',
			)
		)
	);

	if ( outer_is_woocommerce_activated() ) {
		// CTA Block: Single Products.
		$wp_customize->add_setting(
			'footer_cta_single_products_toggle',
			array(
				'default'           => $settings['footer_cta_single_products_toggle'],
				'transport'         => 'postMessage',
				'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
			)
		);
		$wp_customize->add_control(
			new Toggle_Switch_Control(
				$wp_customize,
				'footer_cta_single_products_toggle',
				array(
					'label'   => __( 'Single Products', 'outer' ),
					'section' => 'outer_footer_settings',
					'type'    => 'checkbox',
				)
			)
		);

		// CTA Block: Shop Archives.
		$wp_customize->add_setting(
			'footer_cta_shop_archives_toggle',
			array(
				'default'           => $settings['footer_cta_shop_archives_toggle'],
				'transport'         => 'postMessage',
				'sanitize_callback' => __NAMESPACE__ . '\sanitize_switch',
			)
		);
		$wp_customize->add_control(
			new Toggle_Switch_Control(
				$wp_customize,
				'footer_cta_shop_archives_toggle',
				array(
					'label'   => __( 'Shop Archives', 'outer' ),
					'section' => 'outer_footer_settings',
					'type'    => 'checkbox',
				)
			)
		);
	}

	// Widget columns.
	$wp_customize->add_setting(
		'footer_widget_cols',
		array(
			'default'           => $settings['footer_widget_cols'],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_key',
		)
	);
	$wp_customize->add_control(
		'footer_widget_cols',
		array(
			'label'       => esc_html__( 'Widget Columns', 'outer' ),
			'description' => esc_html__( 'Choose a footer column layout for your site.', 'outer' ),
			'type'        => 'select',
			'section'     => 'outer_footer_settings',
			'choices'     => array(
				0 => esc_html_x( 'Hidden', 'name of the first layout option', 'outer' ),
				1 => esc_html_x( '1 Column', 'name of the second layout option', 'outer' ),
				2 => esc_html_x( '2 Column', 'name of the third layout option', 'outer' ),
				3 => esc_html_x( '3 Column', 'name of the fourth layout option', 'outer' ),
				4 => esc_html_x( '4 Column', 'name of the fifth layout option', 'outer' ),
			),
		)
	);

	// Footer text.
	$wp_customize->add_setting(
		'footer_text',
		array(
			'default'           => $settings['footer_text'],
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		'footer_text',
		array(
			'label'   => esc_html__( 'Footer text', 'outer' ),
			'section' => 'outer_footer_settings',
			'type'    => 'text',
		)
	);

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_block',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_homepage_toggle',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_single_posts_toggle',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_blog_archives_toggle',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_single_products_toggle',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'footer_cta_shop_archives_toggle',
			array(
				'selector'        => '.site-footer__cta',
				'render_callback' => '\\Outer\\display_footer_cta',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'footer_widget_cols',
			array(
				'selector'        => '.footer-widget-area',
				'render_callback' => '\\Outer\\footer_widgets',
			)
		);
	}
}
